#!/usr/bin/env python
from setuptools import setup, find_packages
from ink.services import __version__

import sys
CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 9)

if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write("""
==========================
Unsupported Python version
==========================
This version of Ink Services library requires Python {}.{}, but you're trying to
install it on Python {}.{}.
This may be because you are using a version of pip that doesn't
understand the python_requires classifier. Make sure you
have pip >= 9.0 and setuptools >= 24.2, then try again:
    $ python -m pip install --upgrade pip setuptools
This will install the latest version of ink-service-lib which works on your
version of Python. If you can't upgrade your pip (or Python), request
an older version of ink-service-lib :
    $ python -m pip install ink-services-lib 
""".format(*(REQUIRED_PYTHON + CURRENT_PYTHON)))
    sys.exit(1)

# the setup
setup(
    name='ink-services-lib',
    version='1.5.3',
    description="Library to simply the usage of Wacom's Ink services, such as Ink Storage, Document Store ",
    url='https://bitbucket.org/wacompa/ink-services-lib/',
    author='Markus Weber',
    author_email='markus.weber@wacom.com',
    license='Apache 2.0 License',
    keywords='universal ink;digital ink',
    packages=find_packages(exclude=('docs', 'tests', 'env')),
    include_package_data=True,
    install_requires=[
        "requests>=2.28.0",
        "PyJWT>=2.8.0",
        "python-dateutil==2.8.2",
        "universal-ink-library>=1.1.0",
        "personal-knowledge-library>=2.0.3",
        "aiohttp[speedups]>3.8.6",
        "orjson>=3.8.0",
        "cryptography>=41.0.7"
    ],
    extras_require={
    },
    tests_require=(
        'pytest',
        'pytest-cov'
    ),
    classifiers=[],
    )
